@@ -5,8 +5,8 @@ function(n, foltime, dist.ev, anc.ev, beta0.ev, dist.cens="weibull", anc.cens, b
     if (length(anc.ev) != length(beta0.ev)) stop("Wrong number of parameters")
     if (length(anc.cens) != length(beta0.cens) || length(anc.cens) != 1) stop("Wrong number of parameters")
     if (length(anc.ev) != length(dist.ev)) stop("Wrong number of parameters")
-    if (!is.na(x) && is.na(beta)) stop("Wrong specification of covariables")
-    if (is.na(x) && !is.na(beta)) stop("Wrong specification of covariables")
+    if (any(!is.na(x)) && all(is.na(beta))) stop("Wrong specification of covariables")
+    if (all(is.na(x)) && any(!is.na(beta))) stop("Wrong specification of covariables")
     if (length(beta0.ev) != 1) stop ("Wrong number of distributions or events")
     if (!is.null(z) && length(z) != 1) stop("Wrong numbers of elements in z")
     if (!is.null(z) && !all(lapply(z, function(x) x[1]) %in% c("unif","weibull","invgauss", "gamma","exp"))) 
